/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sis.internal.storage;

import org.apache.sis.storage.DataStore;
import org.apache.sis.storage.Resource;


/**
 * A resource produced by a data store. This interface provides information about which {@link DataStore}
 * produced that resource. It allows for example to fetch the parameters used for opening the data store.
 *
 * <p>This interface is not yet in public API. Whether we should commit this interface in public API is an
 * open question. See <a href="https://issues.apache.org/jira/browse/SIS-416">SIS-416</a>.</p>
 *
 * @author  Johann Sorel (Geomatys)
 * @author  Martin Desruisseaux (Geomatys)
 * @version 1.0
 * @since   1.0
 * @module
 */
public interface StoreResource extends Resource {
    /**
     * Returns the data store that produced this resource.
     *
     * @return the data store that created this resource.
     */
    DataStore getOriginator();
}
